@@ -8,37 +8,41 @@ import (
 
 func TestNewOption(t *testing.T) {
 	cases := []struct {
-		updateType  string
-		name        string
-		version     string
-		platforms   []string
-		recursive   bool
-		ignorePaths []string
-		want        Option
-		ok          bool
+		updateType      string
+		name            string
+		version         string
+		platforms       []string
+		recursive       bool
+		ignorePaths     []string
+		sourceMatchType string
+		want            Option
+		ok              bool
 	}{
 		{
-			updateType:  "terraform",
-			version:     "0.12.7",
-			platforms:   []string{},
-			recursive:   true,
-			ignorePaths: []string{},
+			updateType:      "terraform",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "full",
 			want: Option{
 				updateType:  "terraform",
 				version:     "0.12.7",
 				platforms:   []string{},
 				recursive:   true,
 				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   nil,
 			},
 			ok: true,
 		},
 		{
-			updateType:  "provider",
-			name:        "aws",
-			version:     "2.23.0",
-			platforms:   []string{},
-			recursive:   true,
-			ignorePaths: []string{},
+			updateType:      "provider",
+			name:            "aws",
+			version:         "2.23.0",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "full",
 			want: Option{
 				updateType:  "provider",
 				name:        "aws",
@@ -46,67 +50,143 @@ func TestNewOption(t *testing.T) {
 				platforms:   []string{},
 				recursive:   true,
 				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   nil,
 			},
 			ok: true,
 		},
 		{
-			updateType:  "terraform",
-			version:     "0.12.7",
-			platforms:   []string{},
-			recursive:   true,
-			ignorePaths: []string{"hoge", "fuga"},
+			updateType:      "terraform",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{"hoge", "fuga"},
+			sourceMatchType: "full",
 			want: Option{
 				updateType:  "terraform",
 				version:     "0.12.7",
 				platforms:   []string{},
 				recursive:   true,
 				ignorePaths: []*regexp.Regexp{regexp.MustCompile("hoge"), regexp.MustCompile("fuga")},
+				nameRegex:   nil,
 			},
 			ok: true,
 		},
 		{
-			updateType:  "terraform",
-			version:     "0.12.7",
-			platforms:   []string{},
-			recursive:   true,
-			ignorePaths: []string{""},
+			updateType:      "terraform",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{""},
+			sourceMatchType: "full",
 			want: Option{
 				updateType:  "terraform",
 				version:     "0.12.7",
 				platforms:   []string{},
 				recursive:   true,
 				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   nil,
 			},
 			ok: true,
 		},
 		{
-			updateType:  "terraform",
-			version:     "0.12.7",
-			platforms:   []string{},
-			recursive:   true,
-			ignorePaths: []string{`\`},
-			want:        Option{},
-			ok:          false,
+			updateType:      "terraform",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{`\`},
+			sourceMatchType: "",
+			want:            Option{},
+			ok:              false,
 		},
 		{
-			updateType:  "lock",
-			version:     "",
-			platforms:   []string{"darwin_arm64", "darwin_amd64", "linux_amd64"},
-			recursive:   true,
-			ignorePaths: []string{},
+			updateType:      "lock",
+			version:         "",
+			platforms:       []string{"darwin_arm64", "darwin_amd64", "linux_amd64"},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "full",
 			want: Option{
 				updateType:  "lock",
 				version:     "",
 				platforms:   []string{"darwin_arm64", "darwin_amd64", "linux_amd64"},
 				recursive:   true,
 				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   nil,
 			},
 			ok: true,
 		},
+		{
+			updateType:      "module",
+			name:            "terraform-aws-modules/vpc/aws",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "full",
+			want: Option{
+				updateType:  "module",
+				name:        "terraform-aws-modules/vpc/aws",
+				version:     "0.12.7",
+				platforms:   []string{},
+				recursive:   true,
+				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   nil,
+			},
+			ok: true,
+		},
+		{
+			updateType:      "module",
+			name:            `terraform-aws-modules\.git/vpc/aws`,
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "regex",
+			want: Option{
+				updateType:  "module",
+				name:        `terraform-aws-modules\.git/vpc/aws`,
+				version:     "0.12.7",
+				platforms:   []string{},
+				recursive:   true,
+				ignorePaths: []*regexp.Regexp{},
+				nameRegex:   regexp.MustCompile(`terraform-aws-modules\.git/vpc/aws`),
+			},
+			ok: true,
+		},
+		{
+			updateType:      "module",
+			name:            "",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "regex",
+			ok:              false,
+		},
+		{
+			updateType:      "module",
+			name:            `\`,
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "regex",
+			ok:              false,
+		},
+		{
+			updateType:      "module",
+			name:            "",
+			version:         "0.12.7",
+			platforms:       []string{},
+			recursive:       true,
+			ignorePaths:     []string{},
+			sourceMatchType: "invalid",
+			ok:              false,
+		},
 	}
 
 	for _, tc := range cases {
-		got, err := NewOption(tc.updateType, tc.name, tc.version, tc.platforms, tc.recursive, tc.ignorePaths)
+		got, err := NewOption(tc.updateType, tc.name, tc.version, tc.platforms, tc.recursive, tc.ignorePaths, tc.sourceMatchType)
 		if tc.ok && err != nil {
 			t.Errorf("NewOption() with updateType = %s, name = %s, version = %s, platforms = %#v, recursive = %t, ignorePath = %#v returns unexpected err: %+v", tc.updateType, tc.name, tc.version, tc.platforms, tc.recursive, tc.ignorePaths, err)
 		}
